# pgeng
Useful functions and classes for PyGame

### Installation
`pip3 install pgeng`

### Documentation
Do help(pgeng.Function) to get the documentation of the function (or possibly class)\
Or do help(pgeng.Package Content) to get the documentation of the functions or classes in a file
```
import pgeng
help(pgeng)
```
---
Thanks to [DaFluffyPotato](https://github.com/DaFluffyPotato) for all his [tutorials](https://youtube.com/playlist?list=PLX5fBCkxJmm1fPSqgn9gyR3qih8yYLvMj)